#!/usr/bin/env python3
"""
How long the bot has been running.
"""
import datetime

from twisted.internet import defer

from module import commands


def setup(bot):
	if "uptime" not in bot.memory:
		bot.memory["uptime"] = datetime.datetime.now()
	bot.memory["idle_callbacks"] = {}


@commands('uptime')
def uptime(bot, trigger):
	""".uptime - Returns the uptime of Fulvia."""
	delta = datetime.timedelta(seconds=round((datetime.datetime.now() -
		bot.memory["uptime"]).total_seconds()))
	bot.msg(f"I've been sitting here for {delta} and I keep going!")


@commands('updick')
def updick(bot, trigger):
	""".updick - Returns the uptime of Fulvia, measured in dicks."""
	if trigger.group(2):
		if trigger.group(2) in bot.users:
			d = defer.Deferred()
			d.addCallback(idleTime, bot)
			bot.memory["idle_callbacks"][trigger.group(2)] = d
			bot.whois(trigger.group(2))
	else:
		delta = datetime.datetime.now() - bot.memory["uptime"]
		bot.msg("8" + "="*delta.days + "D")


@commands('upwulf')
def upwulf(bot, trigger):
	""".upwulf - Returns the uptime of Fulvia, measured in Adalwulfs."""
	if trigger.group(2):
		if trigger.group(2) in bot.users:
			d = defer.Deferred()
			d.addCallback(idleTimeWulf, bot)
			bot.memory["idle_callbacks"][trigger.group(2)] = d
			bot.whois(trigger.group(2))
	else:
		delta = datetime.datetime.now() - bot.memory["uptime"]
		bot.msg("Adalwulf" + "_"*delta.days)


def idleTime(result, bot):
	"""
	result - tuple containing (nick, idle, signon)
	"""
	nick, idle, signon = result
	t = datetime.datetime.fromtimestamp(int(signon))
	delta = datetime.datetime.now() - t
	bot.msg("8" + "="*delta.days + "D")


def idleTimeWulf(result, bot):
	"""
	result - tuple containing (nick, idle, signon)
	"""
	nick, idle, signon = result
	t = datetime.datetime.fromtimestamp(int(signon))
	delta = datetime.datetime.now() - t
	bot.msg("Adalwulf" + "_"*delta.days)
